predict_from_coefs: Computes predicted values given coefficients

View source: R/predict_from_coefs.R

predict_from_coefsR Documentation

Computes predicted values given coefficients

Description

This function takes a data frame of coefficients in the form outputted by functions like multiple_linear_regression or ridge_regression.

Usage

predict_from_coefs(dat, response, coefs)

Arguments

dat

A data frame

response

The name of a response variable in the data frame (unquoted)

coefs

A data frame of coefficient estimates

Details

It calculates the predicted values of a response variable from these coefficients.

Value

A data frame of true and predicted values


mknauss58/431-Lab-5-Group documentation built on May 7, 2022, 12:08 a.m.