simple_linear_regression: Implements simple linear regression by hand

View source: R/linear_regression.R

simple_linear_regressionR Documentation

Implements simple linear regression by hand

Description

Implements simple linear regression by hand

Usage

simple_linear_regression(dat, response, explanatory)

Arguments

dat

A data frame

response

The name of a response variable in the data frame (unquoted)

explanatory

The name of the explanatory variable in the data frame (unquoted)

Value

A data frame of coefficients


mknauss58/431-Lab-5-Group documentation built on May 7, 2022, 12:08 a.m.