View source: R/predict_from_coefs.R
| predict_from_coefs | R Documentation |
This function takes a data frame of coefficients in the form outputted by
functions like multiple_linear_regression or ridge_regression.
predict_from_coefs(dat, response, coefs)
dat |
A data frame |
response |
The name of a response variable in the data frame (unquoted) |
coefs |
A data frame of coefficient estimates |
It calculates the predicted values of a response variable from these coefficients.
A data frame of true and predicted values
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.